@@ -150,7 +150,7 @@ class _InlineFunction(XPathFunction):
             if context is None:
                 raise self.missing_context()
             elif not args and self:
-                if context.item is None:
+                if isinstance(context.item, DocumentNode):
                     if isinstance(context.root, DocumentNode):
                         context.item = context.root.getroot()
                     else:
@@ -1053,8 +1053,6 @@ def evaluate_path_function(self, context=None):
     if isinstance(context, XPathSchemaContext):
         return []
     elif not self:
-        if context.item is None:
-            return '/'
         item = context.item
     else:
         item = self.get_argument(context)
@@ -1086,8 +1084,12 @@ def evaluate_path_function(self, context=None):
 
     if isinstance(context.root, DocumentNode):
         root = context.root.getroot().elem
-        path = f'/Q{root.tag}[1]'
+        if root.tag.startswith('{'):
+            path = f'/Q{root.tag}[1]'
+        else:
+            path = f'/Q{{}}{root.tag}[1]'
     else:
+        # If root is an element use the function that returns the root of the tree
         root = context.root.elem
         path = 'Q{%s}root()' % XPATH_FUNCTIONS_NAMESPACE
 
@@ -1113,9 +1115,6 @@ def evaluate_has_children_function(self, context=None):
         raise self.missing_context()
 
     if not self:
-        if context.item is None:
-            return isinstance(context.root, DocumentNode)
-
         item = context.item
         if not isinstance(item, XPathNode):
             raise self.error('XPTY0004', 'context item must be a node')
@@ -1440,8 +1439,7 @@ def evaluate_parse_xml_fragment_function(self, context=None):
         else:
             root = etree.XML(arg)
     except etree.ParseError as err:
-        # A DocumentNode with more children (maybe elements), so
-        # parse the XML including it in a dummy element.
+        # A not parsable fragment try to parse including XML data in a dummy element.
         try:
             dummy_element_node = get_node_tree(
                 root=etree.XML(f'<document>{arg}</document>'),
@@ -1449,32 +1447,14 @@ def evaluate_parse_xml_fragment_function(self, context=None):
             )
         except etree.ParseError:
             raise self.error('FODC0006', str(err)) from None
+        else:
+            return DocumentNode.from_element_node(dummy_element_node)
     else:
         return get_node_tree(
             root=etree.ElementTree(root),
             namespaces=self.parser.namespaces
         )
 
-    # Manually build the DocumentNode, removing the dummy element.
-    root_node = None
-    for child in dummy_element_node:
-        if isinstance(child, ElementNode):
-            root_node = child
-            break
-
-    if root_node is not None:
-        document = etree.ElementTree(root_node.elem)
-    else:
-        document = etree.ElementTree()
-
-    document_node = DocumentNode(document)
-    for child in dummy_element_node:
-        document_node.children.append(child)
-        child.parent = document_node
-
-    dummy_element_node.children.clear()
-    return document_node
-
 
 @method(function('serialize', nargs=(1, 2), sequence_types=(
         'item()*', 'element(output:serialization-parameters)?', 'xs:string')))
